gchecky.model.risk_information_notification_t

Package gchecky :: Module model :: Class risk_information_notification_t |
[hide private]
[frames] | no frames]

# Class risk_information_notification_t

source code

         object --+
                  |
          gxml.Node --+
                      |
          gxml.Document --+
                          |
    abstract_notification_t --+
                              |
                             risk_information_notification_t

Nested Classes | [hide private]
Inherited from `gxml.Document`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Document`: `__str__`, `toxml` Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `gxml.Document`: `fromxml` Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| tag_name = ``'``risk-information-notification``'`` The document's unique xml tag name.
| risk_information = `Node:PATH(risk-information):REQ:{ risk_info`...``
| _fields = ``{``'``google_order_number``'``:` ID:PATH(google-order-number)`...`` list of meta-Fields of this class.
Inherited from `abstract_notification_t`: `google_order_number`, `serial_number`, `timestamp`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### risk_information Value:
      Node:PATH(risk-information):REQ:{ risk_information_t }

  ### _fields list of meta-Fields of this class. Value:
      {'google_order_number': ID:PATH(google-order-number):REQ,
       'risk_information': Node:PATH(risk-information):REQ:{ risk_informatio
      n_t },
       'serial_number': ID:PATH(@serial-number):REQ,
       'timestamp': Timestamp:PATH(timestamp):REQ}